#include "browsedirectoryitem.h"
#include "xinemacontrol.h"
#include "xinemacontrolitem.h"

BrowseDirectoryItem::BrowseDirectoryItem():
	control(0)
{ }

void BrowseDirectoryItem::set_control(XinemaControlItem *c)
{
	if(control)
		disconnect(&control->get_control(), 0, this, 0);

	control = c;
	if(control)
	{
		XinemaControl &xc = control->get_control();
		connect(&xc, &XinemaControl::directory_started, this, &BrowseDirectoryItem::directory_started);
		connect(&xc, &XinemaControl::file_added, this, &BrowseDirectoryItem::file_added);
		connect(&xc, &XinemaControl::subdirectory_added, this, &BrowseDirectoryItem::subdirectory_added);
	}

	emit control_changed();
}

void BrowseDirectoryItem::set_directory(const QString &d)
{
	if(d==directory)
		return;

	directory = d;
	if(control)
		control->get_control().list_directory(directory);
	emit directory_changed();
}

void BrowseDirectoryItem::directory_started(const QString &dir)
{
	if(dir!=directory)
	{
		directory = dir;
		emit directory_changed();
	}

	model.clear();
	if(directory!="/")
		model.add_entry("..", DirectoryModel::ParentDir);
}

void BrowseDirectoryItem::file_added(const QString &name)
{
	model.add_entry(name, DirectoryModel::File);
}

void BrowseDirectoryItem::subdirectory_added(const QString &name)
{
	model.add_entry(name, DirectoryModel::SubDir);
}
